#!/usr/bin/python3 -u
# -*- coding: utf-8 -*-
#
# Copyright 2016 Collabora Ltd.
#
# SPDX-License-Identifier: MPL-2.0
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

import os
import subprocess
import sys

CHECKOUT='checkout'
WORKSPACE=os.getcwd()

outputfile = open("phabricator-comment", "w")
def output(data):
    outputfile.write(data)
    sys.stdout.write(data)

def run_with_output(cmd):
    proc = subprocess.Popen(cmd,
         stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
         universal_newlines=True)

    for data in proc.stdout:
        output(data)

    proc.wait()
    if proc.returncode:
        output("{} failed, return code: {}\n".format(cmd, proc.returncode))
        sys.exit(1)

repository = os.environ['URI']

output("Checking out repository: {}\n".format(repository))

os.environ['GIT_SSH_COMMAND'] = 'ssh -o StrictHostKeyChecking=no'

if 'GIT_SSH_KEY' in os.environ:
    os.environ['GIT_SSH_COMMAND'] += ' -i "%s"' % os.environ['GIT_SSH_KEY']

cmd = [ 'git', 'clone', repository, CHECKOUT ]
run_with_output(cmd)

os.chdir(CHECKOUT)

cmd = [ 'git', 'phab', '--arcrc', os.environ['ARCRC'], 'apply', 'D%s' % os.environ['REVISION'] ]
run_with_output(cmd)

# On success remove the comment file
os.chdir(WORKSPACE)
os.unlink("phabricator-comment")

